package net.sf.moholy.web.servlet.modelAndView;

import org.hamcrest.Description;
import org.hamcrest.Factory;
import org.hamcrest.TypeSafeMatcher;
import org.springframework.web.servlet.ModelAndView;

/**
 * Has the {@code ModelAndView}'s model an attribute with the specified name?
 * 
 * @author Stefan Birkner
 */
public class HasModelAttribute extends TypeSafeMatcher<ModelAndView> {
	private final String attributeName;

	private HasModelAttribute(String attributeName) {
		this.attributeName = attributeName;
	}

	public void describeTo(Description description) {
        description.appendText(attributeName);
	}

	@Override
	public boolean matchesSafely(ModelAndView modelAndView) {
		return modelAndView.getModelMap().containsAttribute(attributeName);
	}

	@Factory
	public static HasModelAttribute hasModelAttribute(String attributeName) {
		return new HasModelAttribute(attributeName);
	}
}
