package net.sf.moholy.web.servlet.modelAndView;

import org.hamcrest.Description;
import org.hamcrest.Factory;
import org.hamcrest.TypeSafeMatcher;
import org.springframework.web.servlet.ModelAndView;

/**
 * Has the {@code ModelAndView}'s model an attribute with the specified name and
 * value?
 * 
 * @author Stefan Birkner
 */
public class HasModelAttributeWithNameAndValue extends TypeSafeMatcher<ModelAndView> {
	private final String attributeName;
	private final String attributeValue;

	private HasModelAttributeWithNameAndValue(String attributeName, String attributeValue) {
		this.attributeName = attributeName;
		this.attributeValue = attributeValue;
	}

	public void describeTo(Description description) {
		StringBuilder text = new StringBuilder();
		text.append("attribute ");
		text.append(quoteText(attributeName));
		text.append(" with value ");
		text.append(quoteText(attributeValue));
		description.appendText(text.toString());
	}

	private String quoteText(String text) {
		return (text == null) ? null : "'" + text + "'";
	}

	@Override
	public boolean matchesSafely(ModelAndView modelAndView) {
		String value = (String) modelAndView.getModelMap().get(attributeName);
		return value == null ? attributeValue == null : value.equals(attributeValue);
	}

	@Factory
	public static HasModelAttributeWithNameAndValue hasModelAttributeWithNameAndValue(
			String attributeName, String attributeValue) {
		return new HasModelAttributeWithNameAndValue(attributeName, attributeValue);
	}
}