package net.sf.moholy.web.servlet.modelAndView;

import org.hamcrest.Description;
import org.hamcrest.Factory;
import org.hamcrest.TypeSafeMatcher;
import org.springframework.web.servlet.ModelAndView;

/**
 * Is the value's view name equal to a specified view name. The value's view
 * name is the one, which is returned by the {@code ModelAndView}'s
 * {@code getViewName()} method.
 * 
 * @author Stefan Birkner
 */
public class HasViewName extends TypeSafeMatcher<ModelAndView> {
	private final String viewName;

	private HasViewName(String viewName) {
		this.viewName = viewName;
	}

	public void describeTo(Description description) {
        description.appendText(viewName);
	}

	@Override
	public boolean matchesSafely(ModelAndView modelAndView) {
		if (viewName == null) {
			return modelAndView.getViewName() == null;
		} else {
			return viewName.equals(modelAndView.getViewName());
		}
	}

	@Factory
	public static HasViewName hasViewName(String viewName) {
		return new HasViewName(viewName);
	}
}
